@@ -22,12 +22,12 @@
 # Boston, MA 02110-1301, USA.
 # 
 
-# See gnuradio-examples/python/gmsk2 for examples
+# See gnuradio-examples/python/digital for examples
 
 from gnuradio import gr
 from gnuradio import modulation_utils
 from math import pi
-import Numeric
+import numpy
 from pprint import pprint
 import inspect
 
@@ -37,7 +37,7 @@ _def_bt = 0.35
 _def_verbose = False
 _def_log = False
 
-_def_gain_mu = 0.05
+_def_gain_mu = None
 _def_mu = 0.5
 _def_freq_error = 0.0
 _def_omega_relative_limit = 0.005
@@ -96,7 +96,7 @@ class gmsk_mod(gr.hier_block):
 		)
 
 	self.sqwave = (1,) * samples_per_symbol       # rectangular window
-	self.taps = Numeric.convolve(Numeric.array(self.gaussian_taps),Numeric.array(self.sqwave))
+	self.taps = numpy.convolve(numpy.array(self.gaussian_taps),numpy.array(self.sqwave))
 	self.gaussian_filter = gr.interp_fir_filter_fff(samples_per_symbol, self.taps)
 
 	# FM modulation
@@ -208,6 +208,9 @@ class gmsk_demod(gr.hier_block):
 
         self._omega = samples_per_symbol*(1+self._freq_error)
 
+        if not self._gain_mu:
+            self._gain_mu = 0.175
+            
 	self._gain_omega = .25 * self._gain_mu * self._gain_mu        # critically damped
 
 	# Demodulate FM
