@@ -24,6 +24,22 @@
 # This is the main GNU Radio python module.
 # We pull the swig output and the other modules into the gnuradio.gr namespace
 
+# Temporary workaround for ticket:181.
+# Use leading underscores to avoid namespace pollution
+import sys
+_RTLD_GLOBAL = 0
+try:
+    from dl import RTLD_GLOBAL as _RTLD_GLOBAL
+except ImportError:
+    try:
+	from DLFCN import RTLD_GLOBAL as _RTLD_GLOBAL
+    except ImportError:
+	pass
+    
+if _RTLD_GLOBAL != 0:
+    _dlopenflags = sys.getdlopenflags()
+    sys.setdlopenflags(_dlopenflags|_RTLD_GLOBAL)
+
 from gnuradio_swig_python import *
 from basic_flow_graph import *
 from flow_graph import *
@@ -32,6 +48,9 @@ from hier_block import *
 from hier_block2 import *
 from top_block import *
 
+if _RTLD_GLOBAL != 0:
+    sys.setdlopenflags(_dlopenflags)             # Restore original flags
+
 # create a couple of aliases
 serial_to_parallel = stream_to_vector
 parallel_to_serial = vector_to_stream
