@@ -88,6 +88,9 @@ class flexrf_base(db_base.db_base):
     def __del__(self):
         #print "flexrf_base.__del__"
         self._u.write_io(self._which, self.power_off, POWER_UP)   # turn off power to board
+	# Power down VCO/PLL
+	self.PD = 3 
+	self._write_control(self._compute_control_reg())
         self._enable_refclk(False)                       # turn off refclk
         self.set_auto_tr(False)
 
@@ -410,15 +413,19 @@ class _AD4360_common(object):
         R = (self.R_RSV<<22) | (self.BSC<<20) | (self.TEST<<19) | (self.LDP<<18) \
             | (self.ABP<<16) | (self.R_DIV<<2)
         
-        control = (self.P<<22) | (self.PD<<20) | (self.CP2<<17) | (self.CP1<<14) | (self.PL<<12) \
-                  | (self.MTLD<<11) | (self.CPG<<10) | (self.CP3S<<9) | (self.PDP<<8) | \
-                  (self.MUXOUT<<5) | (self.CR<<4) | (self.PC<<2)
+        control = self._compute_control_reg()
 
         N = (self.DIVSEL<<23) | (self.DIV2<<22) | (self.CPGAIN<<21) | (self.B_DIV<<8) | \
             (self.N_RSV<<7) | (self.A_DIV<<2)
 
         return (R,control,N,actual_freq/self.freq_mult)
 
+    def _compute_control_reg(self):
+        control = (self.P<<22) | (self.PD<<20) | (self.CP2<<17) | (self.CP1<<14) | (self.PL<<12) \
+                  | (self.MTLD<<11) | (self.CPG<<10) | (self.CP3S<<9) | (self.PDP<<8) | \
+                  (self.MUXOUT<<5) | (self.CR<<4) | (self.PC<<2)
+	return control    
+
     def _refclk_divisor(self):
         """
         Return value to stick in REFCLK_DIVISOR register
@@ -552,15 +559,15 @@ class _400_common(_AD4360_common):
 #------------------------------------------------------------    
 class db_flexrf_2400_tx(_2400_common, flexrf_base_tx):
     def __init__(self, usrp, which):
-        self.power_on = ~POWER_UP
-        self.power_off = ~POWER_UP    # powering it off kills the serial bus
+        self.power_on = 0
+        self.power_off = 0    # powering it off kills the serial bus
         flexrf_base_tx.__init__(self, usrp, which)
         _2400_common.__init__(self)
         
 class db_flexrf_2400_rx(_2400_common, flexrf_base_rx):
     def __init__(self, usrp, which):
-        self.power_on = ~POWER_UP
-        self.power_off = ~POWER_UP   # Powering it off kills the serial bus
+        self.power_on = 0
+        self.power_off = 0   # Powering it off kills the serial bus
         flexrf_base_rx.__init__(self, usrp, which)
         _2400_common.__init__(self)
 
@@ -578,15 +585,15 @@ class db_flexrf_2400_rx(_2400_common, flexrf_base_rx):
 
 class db_flexrf_1200_tx(_1200_common, flexrf_base_tx):
     def __init__(self, usrp, which):
-        self.power_on = ~POWER_UP
-        self.power_off = ~POWER_UP    # powering it off kills the serial bus
+        self.power_on = 0
+        self.power_off = 0    # powering it off kills the serial bus
         flexrf_base_tx.__init__(self, usrp, which)
         _1200_common.__init__(self)
         
 class db_flexrf_1200_rx(_1200_common, flexrf_base_rx):
     def __init__(self, usrp, which):
-        self.power_on = ~POWER_UP
-        self.power_off = ~POWER_UP    # powering it off kills the serial bus
+        self.power_on = 0
+        self.power_off = 0    # powering it off kills the serial bus
         flexrf_base_rx.__init__(self, usrp, which)
         _1200_common.__init__(self)
 
@@ -604,15 +611,15 @@ class db_flexrf_1200_rx(_1200_common, flexrf_base_rx):
 
 class db_flexrf_1800_tx(_1800_common, flexrf_base_tx):
     def __init__(self, usrp, which):
-        self.power_on = ~POWER_UP
-        self.power_off = ~POWER_UP    # powering it off kills the serial bus
+        self.power_on = 0
+        self.power_off = 0    # powering it off kills the serial bus
         flexrf_base_tx.__init__(self, usrp, which)
         _1800_common.__init__(self)
         
 class db_flexrf_1800_rx(_1800_common, flexrf_base_rx):
     def __init__(self, usrp, which):
-        self.power_on = ~POWER_UP
-        self.power_off = ~POWER_UP    # powering it off kills the serial bus
+        self.power_on = 0
+        self.power_off = 0    # powering it off kills the serial bus
         flexrf_base_rx.__init__(self, usrp, which)
         _1800_common.__init__(self)
 
@@ -630,15 +637,15 @@ class db_flexrf_1800_rx(_1800_common, flexrf_base_rx):
 
 class db_flexrf_900_tx(_900_common, flexrf_base_tx):
     def __init__(self, usrp, which):
-        self.power_on = ~POWER_UP
-        self.power_off = ~POWER_UP    # powering it off kills the serial bus
+        self.power_on = 0
+        self.power_off = 0    # powering it off kills the serial bus
         flexrf_base_tx.__init__(self, usrp, which)
         _900_common.__init__(self)
         
 class db_flexrf_900_rx(_900_common, flexrf_base_rx):
     def __init__(self, usrp, which):
-        self.power_on = ~POWER_UP
-        self.power_off = ~POWER_UP    # powering it off kills the serial bus
+        self.power_on = 0
+        self.power_off = 0    # powering it off kills the serial bus
         flexrf_base_rx.__init__(self, usrp, which)
         _900_common.__init__(self)
 
@@ -657,14 +664,14 @@ class db_flexrf_900_rx(_900_common, flexrf_base_rx):
 class db_flexrf_400_tx(_400_common, flexrf_base_tx):
     def __init__(self, usrp, which):
         self.power_on = POWER_UP
-        self.power_off = ~POWER_UP
+        self.power_off = 0
         flexrf_base_tx.__init__(self, usrp, which)
         _400_common.__init__(self)
         
 class db_flexrf_400_rx(_400_common, flexrf_base_rx):
     def __init__(self, usrp, which):
         self.power_on = POWER_UP
-        self.power_off = ~POWER_UP
+        self.power_off = 0
         flexrf_base_rx.__init__(self, usrp, which)
         _400_common.__init__(self)
 
