@@ -22,7 +22,7 @@
 __all__ = ['tv_rx']
 
 import math
-import usrp_dbid
+from usrpm import usrp_dbid
 import db_base
 import db_instantiator
 
