@@ -32,15 +32,16 @@ default_fftsink_size = (640,240)
 default_fft_rate = gr.prefs().get_long('wxgui', 'fft_rate', 15)
 
 class fft_sink_base(object):
-    def __init__(self, input_is_real=False, baseband_freq=0, y_per_div=10, ref_level=50,
+    def __init__(self, input_is_real=False, baseband_freq=0, y_per_div=10, 
+                 y_divs=8, ref_level=50,
                  sample_rate=1, fft_size=512,
                  fft_rate=default_fft_rate,
                  average=False, avg_alpha=None, title='', peak_hold=False):
 
         # initialize common attributes
         self.baseband_freq = baseband_freq
-        self.y_divs = 8
         self.y_per_div=y_per_div
+        self.y_divs = y_divs
         self.ref_level = ref_level
         self.sample_rate = sample_rate
         self.fft_size = fft_size
@@ -90,8 +91,8 @@ class fft_sink_base(object):
         
 
 class fft_sink_f(gr.hier_block2, fft_sink_base):
-    def __init__(self, parent, baseband_freq=0,
-                 y_per_div=10, ref_level=50, sample_rate=1, fft_size=512,
+    def __init__(self, parent, baseband_freq=0, ref_scale=2.0,
+                 y_per_div=10, y_divs=8, ref_level=50, sample_rate=1, fft_size=512,
                  fft_rate=default_fft_rate, average=False, avg_alpha=None,
                  title='', size=default_fftsink_size, peak_hold=False):
 
@@ -100,7 +101,7 @@ class fft_sink_f(gr.hier_block2, fft_sink_base):
                                 gr.io_signature(0,0,0))
 
         fft_sink_base.__init__(self, input_is_real=True, baseband_freq=baseband_freq,
-                               y_per_div=y_per_div, ref_level=ref_level,
+                               y_per_div=y_per_div, y_divs=y_divs, ref_level=ref_level,
                                sample_rate=sample_rate, fft_size=fft_size,
                                fft_rate=fft_rate,
                                average=average, avg_alpha=avg_alpha, title=title,
@@ -121,7 +122,10 @@ class fft_sink_f(gr.hier_block2, fft_sink_base):
 
         # FIXME  We need to add 3dB to all bins but the DC bin
         self.log = gr.nlog10_ff(20, self.fft_size,
-                               -20*math.log10(self.fft_size)-10*math.log10(power/self.fft_size))
+                               -10*math.log10(self.fft_size)		# Adjust for number of bins
+			       -10*math.log10(power/self.fft_size)	# Adjust for windowing loss
+			       -20*math.log10(ref_scale/2))		# Adjust for reference scale
+			       
         self.sink = gr.message_sink(gr.sizeof_float * self.fft_size, self.msgq, True)
 	self.connect(self, self.s2p, self.one_in_n, self.fft, self.c2mag, self.avg, self.log, self.sink)
 
@@ -130,8 +134,8 @@ class fft_sink_f(gr.hier_block2, fft_sink_base):
 
 
 class fft_sink_c(gr.hier_block2, fft_sink_base):
-    def __init__(self, parent, baseband_freq=0,
-                 y_per_div=10, ref_level=50, sample_rate=1, fft_size=512,
+    def __init__(self, parent, baseband_freq=0, ref_scale=2.0,
+                 y_per_div=10, y_divs=8, ref_level=50, sample_rate=1, fft_size=512,
                  fft_rate=default_fft_rate, average=False, avg_alpha=None,
                  title='', size=default_fftsink_size, peak_hold=False):
 
@@ -140,7 +144,7 @@ class fft_sink_c(gr.hier_block2, fft_sink_base):
                                 gr.io_signature(0,0,0))
 
         fft_sink_base.__init__(self, input_is_real=False, baseband_freq=baseband_freq,
-                               y_per_div=y_per_div, ref_level=ref_level,
+                               y_per_div=y_per_div, y_divs=y_divs, ref_level=ref_level,
                                sample_rate=sample_rate, fft_size=fft_size,
                                fft_rate=fft_rate,
                                average=average, avg_alpha=avg_alpha, title=title,
@@ -161,7 +165,10 @@ class fft_sink_c(gr.hier_block2, fft_sink_base):
 
         # FIXME  We need to add 3dB to all bins but the DC bin
         self.log = gr.nlog10_ff(20, self.fft_size,
-                                -20*math.log10(self.fft_size)-10*math.log10(power/self.fft_size))
+                                -10*math.log10(self.fft_size)		# Adjust for number of bins
+				-10*math.log10(power/self.fft_size)	# Adjust for windowing loss
+				-20*math.log10(ref_scale/2))		# Adjust for reference scale
+				
         self.sink = gr.message_sink(gr.sizeof_float * self.fft_size, self.msgq, True)
 	self.connect(self, self.s2p, self.one_in_n, self.fft, self.c2mag, self.avg, self.log, self.sink)
 
@@ -225,20 +232,42 @@ class fft_window (plot.PlotCanvas):
         self.fftsink = fftsink
         self.peak_hold = False
         self.peak_vals = None
-
+        
         self.SetEnableGrid (True)
         # self.SetEnableZoom (True)
         # self.SetBackgroundColour ('black')
         
         self.build_popup_menu()
-        
+	self.set_baseband_freq(0.0)
+	        
         EVT_DATA_EVENT (self, self.set_data)
         wx.EVT_CLOSE (self, self.on_close_window)
         self.Bind(wx.EVT_RIGHT_UP, self.on_right_click)
-
+        self.Bind(wx.EVT_MOTION, self.evt_motion)
+	
         self.input_watcher = input_watcher(fftsink.msgq, fftsink.fft_size, self)
 
+    def set_scale(self, freq):
+	x = max(abs(self.fftsink.sample_rate), abs(self.fftsink.baseband_freq))	
+        if x >= 1e9:
+            self._scale_factor = 1e-9
+            self._units = "GHz"
+	    self._format = "%3.6f"
+        elif x >= 1e6:
+            self._scale_factor = 1e-6
+            self._units = "MHz"
+	    self._format = "%3.3f"
+        else:
+            self._scale_factor = 1e-3
+            self._units = "kHz"
+	    self._format = "%3.3f"
 
+    def set_baseband_freq(self, baseband_freq):
+	if self.peak_hold:
+	    self.peak_vals = None
+	self.set_scale(baseband_freq)
+	self.fftsink.set_baseband_freq(baseband_freq)
+	
     def on_close_window (self, event):
         print "fft_window:on_close_window"
         self.keep_running = False
@@ -255,43 +284,31 @@ class fft_window (plot.PlotCanvas):
                 self.peak_vals = numpy.maximum(dB, self.peak_vals)
                 dB = self.peak_vals
 
-        x = max(abs(self.fftsink.sample_rate), abs(self.fftsink.baseband_freq))
-        if x >= 1e9:
-            sf = 1e-9
-            units = "GHz"
-        elif x >= 1e6:
-            sf = 1e-6
-            units = "MHz"
-        else:
-            sf = 1e-3
-            units = "kHz"
-
         if self.fftsink.input_is_real:     # only plot 1/2 the points
-            x_vals = ((numpy.arange (L/2)
-                       * (self.fftsink.sample_rate * sf / L))
-                      + self.fftsink.baseband_freq * sf)
-            points = numpy.zeros((len(x_vals), 2), numpy.float64)
-            points[:,0] = x_vals
-            points[:,1] = dB[0:L/2]
+            x_vals = ((numpy.arange (L/2) * (self.fftsink.sample_rate 
+	               * self._scale_factor / L))
+                      + self.fftsink.baseband_freq * self._scale_factor)
+            self._points = numpy.zeros((len(x_vals), 2), numpy.float64)
+            self._points[:,0] = x_vals
+            self._points[:,1] = dB[0:L/2]
         else:
             # the "negative freqs" are in the second half of the array
             x_vals = ((numpy.arange (-L/2, L/2)
-                       * (self.fftsink.sample_rate * sf / L))
-                      + self.fftsink.baseband_freq * sf)
-            points = numpy.zeros((len(x_vals), 2), numpy.float64)
-            points[:,0] = x_vals
-            points[:,1] = numpy.concatenate ((dB[L/2:], dB[0:L/2]))
-
-
-        lines = plot.PolyLine (points, colour='BLUE')
+                       * (self.fftsink.sample_rate * self._scale_factor / L))
+                      + self.fftsink.baseband_freq * self._scale_factor)
+            self._points = numpy.zeros((len(x_vals), 2), numpy.float64)
+            self._points[:,0] = x_vals
+            self._points[:,1] = numpy.concatenate ((dB[L/2:], dB[0:L/2]))
 
+        lines = plot.PolyLine (self._points, colour='BLUE')
         graphics = plot.PlotGraphics ([lines],
                                       title=self.fftsink.title,
-                                      xLabel = units, yLabel = "dB")
+                                      xLabel = self._units, yLabel = "dB")
 
         self.Draw (graphics, xAxis=None, yAxis=self.y_range)
         self.update_y_range ()
 
+
     def set_peak_hold(self, enable):
         self.peak_hold = enable
         self.peak_vals = None
@@ -341,7 +358,6 @@ class fft_window (plot.PlotCanvas):
         elif Id == self.id_y_per_div_20:
             self.fftsink.set_y_per_div(20)
 
-        
     def on_right_click(self, event):
         menu = self.popup_menu
         for id, pred in self.checkmarks.items():
@@ -349,7 +365,28 @@ class fft_window (plot.PlotCanvas):
             item.Check(pred())
         self.PopupMenu(menu, event.GetPosition())
 
+    def evt_motion(self, event):
+        # Clip to plotted values
+        (ux, uy) = self.GetXY(event)      # Scaled position
+        x_vals = numpy.array(self._points[:,0])
+        if ux < x_vals[0] or ux > x_vals[-1]:
+            tip = self.GetToolTip()
+            if tip:
+                tip.Enable(False)
+            return
 
+        # Get nearest X value (is there a better way)?
+        ind = numpy.argmin(numpy.abs(x_vals-ux))
+        x_val = x_vals[ind]
+        db_val = self._points[ind, 1]
+        text = (self._format+" %s dB=%3.3f") % (x_val, self._units, db_val)
+
+        # Display the tooltip
+        tip = wx.ToolTip(text)
+        tip.Enable(True)
+        tip.SetDelay(0)
+        self.SetToolTip(tip)
+        
     def build_popup_menu(self):
         self.id_incr_ref_level = wx.NewId()
         self.id_decr_ref_level = wx.NewId()
@@ -362,7 +399,7 @@ class fft_window (plot.PlotCanvas):
         self.id_y_per_div_20 = wx.NewId()
         self.id_average = wx.NewId()
         self.id_peak_hold = wx.NewId()
-
+	
         self.Bind(wx.EVT_MENU, self.on_average, id=self.id_average)
         self.Bind(wx.EVT_MENU, self.on_peak_hold, id=self.id_peak_hold)
         self.Bind(wx.EVT_MENU, self.on_incr_ref_level, id=self.id_incr_ref_level)
@@ -374,8 +411,7 @@ class fft_window (plot.PlotCanvas):
         self.Bind(wx.EVT_MENU, self.on_y_per_div, id=self.id_y_per_div_5)
         self.Bind(wx.EVT_MENU, self.on_y_per_div, id=self.id_y_per_div_10)
         self.Bind(wx.EVT_MENU, self.on_y_per_div, id=self.id_y_per_div_20)
-
-
+        
         # make a menu
         menu = wx.Menu()
         self.popup_menu = menu
